
# Slot: object


the material entity the sample was derived from. This may be another material sample, or any other material entity, including for example an organism, a geographic feature, or some environmental material.

URI: [biolink:material_sample_derivation_association_object](https://w3id.org/biolink/vocab/material_sample_derivation_association_object)


## Domain and Range

[MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md) &#8594;  <sub>1..1</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md)
